import type { InventoryVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  inventoryExport = '/eims/inventory/export',
  inventoryList = '/eims/inventory/list',
  root = '/eims/inventory'
}

/**
 * 查询盘点列表
 * @param query
 * @returns {*}
 */

export function listInventory(params?: any) {
  return requestClient.get<InventoryVO[]>(Api.inventoryList, { params });
}

/**
 * 查询盘点详细
 * @param inventoryId
 */
export function getInventory(inventoryId: ID) {
  return requestClient.get<InventoryVO>(`${Api.root}/${inventoryId}`);
}

/**
 * 新增盘点
 * @param data
 */
export function addInventory(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改盘点
 * @param data
 */
export function updateInventory(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除盘点
 * @param inventoryId
 */
export function delInventory(inventoryId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${inventoryId}`);
}
/**
 * 导出
 * @param
 */
export function inventoryExport(data: any) {
  return commonExport(Api.inventoryExport, data);
}
